#
# spec file for package cim-schema
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cim-schema
Version:        2.54.0
Release:        1.6
Summary:        Common Information Model (CIM) Schema
License:        SUSE-DMTF
Group:          System/Management
URL:            http://www.dmtf.org/
Source0:        http://www.dmtf.org/sites/default/files/cim/cim_schema_v2530/cim_schema_%{version}Experimental-MOFs.zip
Source1:        loadmof.sh
Source2:        rmmof.sh
BuildRequires:  unzip
# openlmi-* requires the experimental variant
Provides:       cim-schema-experimental = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Common Information Model (CIM) is a model for describing overall
management information in a network or enterprise environment. CIM
consists of a specification and a schema. The specification defines the
details for integration with other management models. The schema
provides the actual model descriptions.

%prep
%setup -q -c

%build

%install
MOFDIR=%{_datadir}/mof
CIMDIR=$MOFDIR/cimv%{version}
for i in `find . -name "*.mof"`; do
  perl -p -i -e 's/\r//g' $i
done
install -d %{buildroot}/$CIMDIR
perl -p -i -e 's/\\/\//g' cim*.mof
echo "" >> qualifiers.mof
echo "// Optional Qualifiers: " >> qualifiers.mof
echo "" >> qualifiers.mof
cat qualifiers_optional.mof >> qualifiers.mof
rm qualifiers_optional.mof
chmod -R go-wx .
chmod -R a+rX .
mv * %{buildroot}/$CIMDIR/
ln -s cimv%{version} %{buildroot}/$MOFDIR/cim-current
pushd %{buildroot}/$CIMDIR/
ln -s cim*.mof CIM_Schema.mof
popd
install -d %{buildroot}%{_prefix}/bin
install -m 755 %{SOURCE1} %{buildroot}%{_bindir}/
install -m 755 %{SOURCE2} %{buildroot}%{_bindir}/
perl -p -i -e 's~^#pragma include ("qualifiers_optional\.mof")~\/\/#pragma include ("qualifiers_optional\.mof")~g' %{buildroot}/$MOFDIR/cim-current/CIM_Schema.mof
perl -p -i -e \
	's~^#pragma include \("qualifiers_optional\.mof"\)~\/\/#pragma include ("qualifiers_optional\.mof")~g' \
	%{buildroot}/$MOFDIR/cim-current/CIM_Schema.mof

%files
%defattr(-, root, root)
%dir %{_datadir}/mof
%dir %{_datadir}/mof/cimv%{version}
%{_datadir}/mof/cimv%{version}/*
%{_datadir}/mof/cim-current
%{_bindir}/loadmof.sh
%{_bindir}/rmmof.sh

%changelog
* Fri Jul  1 2022 Klaus Kämpf <kkaempf@suse.com>
- Upgrade to version 2.54.0
  http://www.dmtf.org/sites/default/files/cim/cim_schema_v2540/releasenotes.html
* Sat Aug 15 2020 Klaus Kämpf <kkaempf@suse.com>
- Upgrade to version 2.53.0
  http://www.dmtf.org/sites/default/files/cim/cim_schema_v2530/releasenotes.html
- Upgrade to version 2.52.0
  http://www.dmtf.org/sites/default/files/cim/cim_schema_v2520/releasenotes.html
- Upgrade to version 2.51.0
  http://www.dmtf.org/sites/default/files/cim/cim_schema_v2510/releasenotes.html
* Wed Jan 10 2018 kkaempf@suse.com
- Upgrade to 2.50.0
  As part of CIM 2.50.0, a number of enhancements and additions are
  introduced throughout the Schema, including ongoing improvements to
  support product and alliance partners and to support DMTF Profiles and
  Management Initiatives.  Examples include updates to BIOS, printers,
  standard messages, operating system state, modern power management
  paradigms, virtualization and security.
  See https://www.dmtf.org/sites/default/files/cim/cim_schema_v2500/releasenotes.html
* Fri Jun 16 2017 kkaempf@suse.com
- Upgrade to version 2.49.0
  http://www.dmtf.org/sites/default/files/cim/cim_schema_v2490/releasenotes.html
- Upgrade to version 2.48.0
  http://www.dmtf.org/sites/default/files/cim/cim_schema_v2480/releasenotes.html
- Upgrade to version 2.47.0
  http://www.dmtf.org/sites/default/files/cim/cim_schema_v2470/releasenotes.html
- Upgrade to version 2.46.0
  http://www.dmtf.org/sites/default/files/cim/cim_schema_v2460/releasenotes.html
* Fri Jan 22 2016 kkaempf@suse.com
- Upgrade to version 2.45.0
  http://www.dmtf.org/sites/default/files/cim/cim_schema_v2450/releasenotes.html
* Mon Jun 22 2015 kstreitova@suse.com
- Upgrade to version 2.44.0
  http://dmtf.org/sites/default/files/cim/cim_schema_v2440/releasenotes.html
- use spec-cleaner
* Thu Feb 26 2015 kkaempf@suse.com
- Upgrade to version 2.43.0
  http://dmtf.org/sites/default/files/cim/cim_schema_v2430/releasenotes.html
* Thu Nov  6 2014 kkaempf@suse.com
- Upgrade to version 2.42.0
  http://www.dmtf.org/sites/default/files/cim/cim_schema_v2420/releasenotes.html
- Upgrade to version 2.41.0
  http://www.dmtf.org/sites/default/files/cim/cim_schema_v2410/releasenotes.html
* Thu Apr 10 2014 kkaempf@suse.com
- Upgrade to version 2.40.0
  http://www.dmtf.org/sites/default/files/cim/cim_schema_v2400/releasenotes.html
* Thu Apr 10 2014 kkaempf@suse.com
- Upgrade to version 2.39.0
  http://www.dmtf.org/sites/default/files/cim/cim_schema_v2390/releasenotes.html
* Thu Sep 26 2013 kkaempf@suse.com
- Upgrade to version 2.38.0
  http://www.dmtf.org/sites/default/files/cim/cim_schema_v2380/releasenotes.html
* Fri Jun 28 2013 kkaempf@suse.com
- Provide cim-schema-experimental explicitly
* Wed Jun 26 2013 kkaempf@suse.com
- Upgrade to version 2.37.0
  http://www.dmtf.org/sites/default/files/cim/cim_schema_v2370/releasenotes.html
* Mon May  6 2013 kkaempf@suse.com
- switch to Experimental schema (for openlmi)
* Fri Apr 12 2013 kkaempf@suse.com
- Upgraded to version 2.36.0
  http://dmtf.org/sites/default/files/cim/cim_schema_v2360/releasenotes.html
  http://dmtf.org/sites/default/files/cim/cim_schema_v2351/releasenotes.html
* Wed Feb 20 2013 kkaempf@suse.com
- Upgraded to version 2.35.0
  http://dmtf.org/sites/default/files/cim/cim_schema_v2350/releasenotes.html
* Fri Feb 10 2012 cfarrell@suse.com
- license update: SUSE-DMTF
  Use SUSE- proprietary prefix until DMTF is accepted upstream at spdx.org
* Thu Oct 20 2011 kkaempf@suse.com
- Update to 2.30.0 (Final)
  Correction to Processor Family name in Application/CIM_ArchitectureCheck.mof.mof
  and Device/CIM_Processor.mof.mof
* Fri Sep 23 2011 kkaempf@suse.com
- Download location changed upstream.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Thu Sep 15 2011 kkaempf@suse.com
- Upgraded to version 2.29.1
  http://dmtf.org/sites/default/files/cim/cim_schema_v2291/releasenotes.html
- Upgraded to version 2.28.0
  http://dmtf.org/sites/default/files/cim/cim_schema_v2280/releasenotes.html
* Mon Jan  3 2011 kkaempf@novell.com
- Upgraded to version 2.27.0 (Final)
  http://dmtf.org/sites/default/files/cim/cim_schema_v2270/releasenotes.html
* Fri Jul 30 2010 kkaempf@novell.com
- Upgraded to version 2.26.0
  * 2.26.0 release notes can be found at
    http://www.dmtf.org/standards/cim/cim_schema_v2260/releasenotes.html
  * 2.25.0 release notes can be found at
    http://www.dmtf.org/standards/cim/cim_schema_v2250/releasenotes.html
  * 2.24.0 release notes can be found at
    http://www.dmtf.org/standards/cim/cim_schema_v2240/releasenotes.html
  * 2.23.0 release notes can be found at
    http://www.dmtf.org/standards/cim/cim_schema_v2230/releasenotes.html
  * 2.22.0 release notes can be found at
    http://www.dmtf.org/standards/cim/cim_schema_v2220/releasenotes.html
* Tue May 26 2009 mhrusecky@suse.cz
- Upgraded to version 2.2.21.0
  * 2.21.0 release notes can be found at
    http://www.dmtf.org/standards/cim/cim_schema_v2210/releasenotes.html
  * 2.20.1 release notes can be found at
    http://www.dmtf.org/standards/cim/cim_schema_v2201/releasenotes.html
* Thu Oct 23 2008 bwhiteley@suse.de
- Upgraded to cimv2.19.1Experimental (bnc#438509)
* Wed Sep  3 2008 mmarek@suse.cz
- don't clean buildroot in %%%%install
* Wed Aug  6 2008 bwhiteley@suse.de
- Upgraded to cimv2.19.0Experimental
* Wed May 14 2008 bwhiteley@suse.de
- Upgraded to cimv2.18Experimental
* Thu Jan 17 2008 bwhiteley@suse.de
- Fixed order of includes so that it will import in pegasus.
* Tue Jan  8 2008 bwhiteley@suse.de
- Updated to cimv2.17Experimental (#341800)
* Wed Nov 28 2007 bwhiteley@suse.de
- Updated to cimv2.16Experimental (#341800)
  Remove carriage returns from MOF files.
  Fix broken comment blocks in 2.16 schema.
* Thu Mar 29 2007 bwhiteley@suse.de
- Added unzip to BuildRequires
* Tue Mar 27 2007 bwhiteley@suse.de
- Fixed inclusion of missing file (#258187)
* Tue Mar 13 2007 bart@novell.com
- Added some classes from 2.15 preliminary needed for Xen
  providers (#228365)
* Fri Jan 19 2007 bwhiteley@suse.de
- update to schema version 2.14 (#228365)
* Mon Jan  8 2007 bwhiteley@suse.de
- Combine all qualifiers back into one file (#232667)
* Tue Dec 19 2006 bwhiteley@suse.de
- added loadmof.sh script. (#228349)
* Wed Dec 13 2006 bwhiteley@suse.de
- Updated to schema version cimv2.13.1 (#228365)
* Sat Oct  7 2006 bwhiteley@suse.de
- Updated to schema version cimv2.13
* Mon May  8 2006 bwhiteley@suse.de
- Updated to schema version cimv2.12, required for SMASH 1.0
  compliance (#173777)
* Fri May  5 2006 bwhiteley@suse.de
- removed non-ascii char from CIM_DNSSettingData.mof (was breaking
  some XML parsers) (#172939)
* Fri Feb 10 2006 bwhiteley@suse.de
- fixed execute bit on directories (#149992)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 bwhiteley@suse.de
- Added a symlink cim-current so other packages don't have to hard-
  code cim schema versions.
* Tue Jan 10 2006 bwhiteley@suse.de
- Update to v2.11 Experimental.
- Moved MOFs under /usr/share/mof
* Thu Jan 13 2005 nashif@suse.de
- Update to v2.9 Final
* Tue Oct 12 2004 nashif@suse.de
- Update with cim v2.9
* Tue Feb 17 2004 nashif@suse.de
- Fixed directory permissions
- build as normal user
* Mon Feb 16 2004 nashif@suse.de
- Updated to 2.8 final
* Thu Nov 27 2003 nashif@suse.de
- Initial Release
